<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xd:doc xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> Jan 11, 2010</xd:p>
            <xd:p><xd:b>Author:</xd:b> Peter Cobcroft</xd:p>
            <xd:p/>
        </xd:desc>
    </xd:doc>

    <xsl:template match="ship">
        <html>
            <head>
                <title>
                    <xsl:value-of select="name"/>
                </title>
                <link>
                    <xsl:attribute name="href">../xsl/colours.css</xsl:attribute>
                    <xsl:attribute name="rel">stylesheet</xsl:attribute>
                    <xsl:attribute name="type">text/css</xsl:attribute>
                    <xsl:attribute name="media">screen</xsl:attribute>
                </link>
            </head>
            <body>
                <h1>Name: <xsl:value-of select="name"/></h1>
                <h2>Registry: <xsl:value-of select="registry"/></h2>
                <h3>Size: <xsl:value-of select="size"/></h3>
                <xsl:apply-templates select="map"/>
            </body>            
        </html>
    </xsl:template>

    <xsl:key name="module-lookup" match="module" use="name"/>

    <xsl:variable name="class" select="document('../setup/modulesetup.xml')/modules"/>

    <xsl:template match="modules">
        <xsl:param name="mname"/>
        <xsl:param name="dname"/>
        <xsl:choose>
            <xsl:when test="$dname">
                <table>
                    <xsl:attribute name="class">
                        <xsl:value-of select="key('module-lookup', $mname/type)/class"/>
                    </xsl:attribute>
                    <xsl:choose>
                        <xsl:when test="$dname='north'">
                            <xsl:call-template name="parseRow">
                                <xsl:with-param name="input">
                                    <xsl:value-of
                                        select="substring(key('module-lookup', $mname/type)/grid/north,1,string-length(key('module-lookup', $mname/type)/grid/north)-1)"
                                    />
                                </xsl:with-param>
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:when test="$dname='east'">
                            <xsl:call-template name="parseRow">
                                <xsl:with-param name="input">
                                    <xsl:value-of
                                        select="substring(key('module-lookup', $mname/type)/grid/east,1,string-length(key('module-lookup', $mname/type)/grid/east)-1)"
                                    />
                                </xsl:with-param>
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:when test="$dname='south'">
                            <xsl:call-template name="parseRow">
                                <xsl:with-param name="input">
                                    <xsl:value-of
                                        select="substring(key('module-lookup', $mname/type)/grid/south,1,string-length(key('module-lookup', $mname/type)/grid/south)-1)"
                                    />
                                </xsl:with-param>
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:when test="$dname='west'">
                            <xsl:call-template name="parseRow">
                                <xsl:with-param name="input">
                                    <xsl:value-of
                                        select="substring(key('module-lookup', $mname/type)/grid/west,1,string-length(key('module-lookup', $mname/type)/grid/west)-1)"
                                    />
                                </xsl:with-param>
                            </xsl:call-template>
                        </xsl:when>
                    </xsl:choose>
                </table>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="key('module-lookup', $mname/type)/class"/>
            </xsl:otherwise>
        </xsl:choose>

    </xsl:template>

    <xsl:template name="parseRow">
        <xsl:param name="input"/>
        <xsl:choose>
            <xsl:when test="substring($input,1,1)=' '">
                <tr>
                    <xsl:call-template name="parseColumn">
                        <xsl:with-param name="input">
                            <xsl:value-of select="substring($input,2)"/>
                        </xsl:with-param>
                    </xsl:call-template>
                </tr>
            </xsl:when>
        </xsl:choose>
        <xsl:if test="string-length($input) &gt; 1">
            <xsl:call-template name="parseRow">
                <xsl:with-param name="input" select="substring($input,2)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>


    <xsl:template name="parseColumn">
        <xsl:param name="input"/>
        <xsl:choose>
            <xsl:when test="substring($input,1,1)='0'">
                <td>
                    <xsl:attribute name="style">
                        <xsl:text>background-color: #FFFFFF;</xsl:text>
                    </xsl:attribute>. </td>
            </xsl:when>
            <xsl:when test="substring($input,1,1)='F'">
                <td>
                    <xsl:attribute name="style">
                        <xsl:text>background-color: #000000;</xsl:text>
                        <xsl:text>color: #FFFFFF;</xsl:text>
                    </xsl:attribute> 6 </td>
            </xsl:when>
            <xsl:when test="substring($input,1,1)='G'">
                <td>
                    <xsl:attribute name="style">
                        <xsl:text>background-color: #000000;</xsl:text>
                        <xsl:text>color: #FFFFFF;</xsl:text>
                    </xsl:attribute> . </td>
            </xsl:when>
            <xsl:when test="substring($input,1,1)='7'">
                <td>. </td>
            </xsl:when>
            <xsl:when test="substring($input,1,1)=' '"> </xsl:when>
            <xsl:otherwise>
                <td>
                    <xsl:attribute name="style">
                        <xsl:text>background-color: #FFFFFF;</xsl:text>
                    </xsl:attribute>
                    <xsl:value-of select="substring($input,1,1)"/>
                </td>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="string-length($input) &gt; 1">
            <xsl:if test="substring($input,1,1)!=' '">
                <xsl:call-template name="parseColumn">
                    <xsl:with-param name="input" select="substring($input,2)"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:if>
    </xsl:template>

    <xsl:template name="axes">
        <!--Show the x and y axes around the map-->
        <xsl:call-template name="createXaxis">
            <xsl:with-param name="total">7</xsl:with-param>
            <xsl:with-param name="counter">1</xsl:with-param>
        </xsl:call-template>
        <xsl:call-template name="createYaxis">
            <xsl:with-param name="total">7</xsl:with-param>
            <xsl:with-param name="Ycounter">1</xsl:with-param>
        </xsl:call-template>
    </xsl:template>


    <xsl:template name="createXaxis">
        <xsl:param name="total"/>
        <xsl:param name="counter"/>
        <xsl:if test="$total &gt;= $counter">
            <div>
                <xsl:attribute name="style">
                    <xsl:text>position: absolute;</xsl:text>
                    <xsl:text>display: block;</xsl:text>
                    <xsl:text>width: 80px;</xsl:text>
                    <xsl:text>height: 35px;</xsl:text>
                    <xsl:text>margin-top: -15px;</xsl:text>
                    <xsl:text>margin-left:</xsl:text>
                    <xsl:value-of select="($counter - 1)*82 + 50"/>
                    <xsl:text>px;</xsl:text>
                    <xsl:text>background-color:#DDDDDD;</xsl:text>
                    <xsl:text>z-index:-1;</xsl:text>
                </xsl:attribute>
                <table>
                    <xsl:attribute name="style">
                        <xsl:text>width: 100%;</xsl:text>
                        <xsl:text>border-width: 2px;</xsl:text>
                        <xsl:text>border-style: solid;</xsl:text>
                        <xsl:text>border-color: #000000;</xsl:text>
                        <xsl:text>background-color:#DDDDDD;</xsl:text>
                        <xsl:text>margin:0px;</xsl:text>
                        <xsl:text>padding:0px;</xsl:text>
                    </xsl:attribute>
                    <tr>
                        <xsl:attribute name="style">
                            <xsl:text>height: 25px;</xsl:text>
                        </xsl:attribute>
                        <th>
                            <xsl:attribute name="colspan">
                                <xsl:text>5</xsl:text>
                            </xsl:attribute>
                            <xsl:value-of select="$counter + 3"/>
                        </th>
                    </tr>
                    <tr>
                        <xsl:attribute name="style">
                            <xsl:text>height: 10px;</xsl:text>
                        </xsl:attribute>
                        <xsl:call-template name="createCell">
                            <xsl:with-param name="cells">5</xsl:with-param>
                            <xsl:with-param name="counter">1</xsl:with-param>
                        </xsl:call-template>
                    </tr>
                </table>
            </div>
            <xsl:call-template name="createXaxis">
                <xsl:with-param name="total">
                    <xsl:value-of select="$total"/>
                </xsl:with-param>
                <xsl:with-param name="counter">
                    <xsl:value-of select="$counter + 1"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="createYaxis">
        <xsl:param name="total"/>
        <xsl:param name="Ycounter"/>
        <xsl:if test="$total &gt;= $Ycounter">
            <div>
                <xsl:attribute name="style">
                    <xsl:text>position: absolute;</xsl:text>
                    <xsl:text>display: block;</xsl:text>
                    <xsl:text>width: 50px;</xsl:text>
                    <xsl:text>height: 80px;</xsl:text>
                    <xsl:text>margin-top:</xsl:text>
                    <xsl:value-of select="($Ycounter - 1)*80 + 30"/>
                    <xsl:text>px;</xsl:text>
                    <xsl:text>margin-left:0px;</xsl:text>
                    <xsl:text>background-color:#DDDDDD;</xsl:text>
                    <xsl:text>z-index:-1;</xsl:text>
                </xsl:attribute>
                <table>
                    <xsl:attribute name="style">
                        <xsl:text>width: 100%;</xsl:text>
                        <xsl:text>height: 100%;</xsl:text>
                        <xsl:text>border-width: 2px;</xsl:text>
                        <xsl:text>border-style: solid;</xsl:text>
                        <xsl:text>border-color: #000000;</xsl:text>
                        <xsl:text>background-color:#DDDDDD;</xsl:text>
                    </xsl:attribute>
                    <xsl:call-template name="createRow">
                        <xsl:with-param name="cells">5</xsl:with-param>
                        <xsl:with-param name="counter">1</xsl:with-param>
                        <xsl:with-param name="rownum">
                            <xsl:value-of select="$Ycounter"/>
                        </xsl:with-param>
                    </xsl:call-template>
                </table>
            </div>
            <xsl:call-template name="createYaxis">
                <xsl:with-param name="total">
                    <xsl:value-of select="$total"/>
                </xsl:with-param>
                <xsl:with-param name="Ycounter">
                    <xsl:value-of select="$Ycounter + 1"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="createRow">
        <xsl:param name="cells"/>
        <xsl:param name="counter"/>
        <xsl:param name="rownum"/>
        <xsl:if test="$cells &gt;= $counter">
            <tr>
                <xsl:if test="$counter = 1">
                    <th>
                        <xsl:attribute name="rowspan">
                            <xsl:text>5</xsl:text>
                        </xsl:attribute>
                        <xsl:value-of select="$rownum + 3"/>
                    </th>               
                </xsl:if>
                <td>
                    <xsl:attribute name="style">
                        <xsl:text>width: 16px;</xsl:text>
                        <xsl:text>margin:0px;</xsl:text>
                        <xsl:text>padding:0px;</xsl:text>
                    </xsl:attribute>
                    <xsl:value-of select="$counter"/>
                </td>
            </tr>
            <xsl:call-template name="createRow">
                <xsl:with-param name="cells">
                    <xsl:value-of select="$cells"/>
                </xsl:with-param>
                <xsl:with-param name="counter">
                    <xsl:value-of select="$counter + 1"/>
                </xsl:with-param>
                <xsl:with-param name="rownum">
                    <xsl:value-of select="$rownum"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="createCell">
        <xsl:param name="cells"/>
        <xsl:param name="counter"/>
        <xsl:if test="$cells &gt;= $counter">
            <td>
                <xsl:attribute name="style">
                    <xsl:text>width: 16px;</xsl:text>
                    <xsl:text>margin:0px;</xsl:text>
                    <xsl:text>padding:0px;</xsl:text>
                </xsl:attribute>
                <xsl:value-of select="$counter"/>
            </td>
            <xsl:call-template name="createCell">
                <xsl:with-param name="cells">
                    <xsl:value-of select="$cells"/>
                </xsl:with-param>
                <xsl:with-param name="counter">
                    <xsl:value-of select="$counter + 1"/>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>


    <xsl:template match="map">
        <div>
            <xsl:attribute name="style">
                <xsl:text>position: absolute;</xsl:text>
                <xsl:text>display: block;</xsl:text>
                <xsl:text>width: 80px;</xsl:text>
                <xsl:text>height: 80px;</xsl:text>
                <xsl:choose>
                    <xsl:when test="enhancement='upgraded'">
                        <xsl:text>border-width: 2px;</xsl:text>
                        <xsl:text>border-style: solid;</xsl:text>
                        <xsl:text>margin-top:</xsl:text>
                        <xsl:value-of select="(number(location/y)-4)*80 + 30"/>
                        <xsl:text>px;</xsl:text>
                        <xsl:text>margin-left:</xsl:text>
                        <xsl:value-of select="(number(location/x)-4)*82 + 50"/>
                        <xsl:text>px;</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>margin-top:</xsl:text>
                        <xsl:value-of select="(number(location/y)-4)*80 + 30"/>
                        <xsl:text>px;</xsl:text>
                        <xsl:text>margin-left:</xsl:text>
                        <xsl:value-of select="(number(location/x)-4)*82 + 50"/>
                        <xsl:text>px;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text>text-align:center;</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="class">
                <xsl:apply-templates select="$class">
                    <xsl:with-param name="mname" select="."/>
                </xsl:apply-templates>
            </xsl:attribute>
            <xsl:apply-templates select="$class">
                <xsl:with-param name="mname" select="."/>
                <xsl:with-param name="dname">
                    <xsl:value-of select="orientation"/>
                </xsl:with-param>
            </xsl:apply-templates>
            <xsl:apply-templates select="enhancement"/>
        </div>
    </xsl:template>

    <xsl:template match="enhancement">
        <xsl:choose>
            <xsl:when test="count(item)>0">
                <xsl:for-each select="item">
                    <div>
                        <xsl:attribute name="class">
                            <xsl:value-of select="@location"/>
                        </xsl:attribute>
                        <xsl:value-of select="."/>
                    </div>
                </xsl:for-each>
            </xsl:when>
        </xsl:choose>

    </xsl:template>

</xsl:stylesheet>
