<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xd:doc xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> Jan 11, 2010</xd:p>
            <xd:p><xd:b>Author:</xd:b> Coder</xd:p>
            <xd:p/>
        </xd:desc>
    </xd:doc>
    <!--    <xsl:output method="html"/>-->

    <xsl:include href="turnshipdisplay.xsl"/>

    <xsl:template match="turn">
        <html>
            <head>
                <title>
                    <xsl:text>Turn: </xsl:text>
                    <xsl:value-of select="number"/>
                </title>
                <link>
                    <xsl:attribute name="href">../xsl/colours.css</xsl:attribute>
                    <xsl:attribute name="rel">stylesheet</xsl:attribute>
                    <xsl:attribute name="type">text/css</xsl:attribute>
                    <xsl:attribute name="media">screen</xsl:attribute>
                </link>
            </head>
            <body>
                <xsl:apply-templates select="number"/>
                <xsl:apply-templates select="playership"/>
                <xsl:apply-templates select="playercrew"/>
            </body>
        </html>
    </xsl:template>

    <!--    Show the turn number-->
    <xsl:template match="number">
        <div>
            <xsl:attribute name="class">turn</xsl:attribute>
            <xsl:text>Turn: </xsl:text>
            <xsl:value-of select="."/>
        </div>
    </xsl:template>

    <!--    Import the ship information -->
    <xsl:template match="playership">
        <xsl:variable name="shipfile">
            <xsl:text>../ships/</xsl:text>
            <xsl:value-of
                select="translate(name,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"> </xsl:value-of>
            <xsl:text>.xml</xsl:text>
        </xsl:variable>
        <xsl:apply-templates select="document($shipfile)"/>
    </xsl:template>


    <!--    Import the crew list-->
    <xsl:template match="playercrew">
        <xsl:variable name="crewfile">
            <xsl:text>../crews/</xsl:text>
            <xsl:value-of
                select="translate(crewlist,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"> </xsl:value-of>
            <xsl:text>.xml</xsl:text>
        </xsl:variable>
        <xsl:apply-templates select="document($crewfile)"/>
        <xsl:apply-templates select="character"/>
    </xsl:template>


    <!--    Display the crew information from the crew list on the right hand side-->
    <xsl:template match="crew">
        <div>
            <xsl:attribute name="class">crewlist</xsl:attribute>
            <xsl:for-each select="crewmember">
                <table>
                    <xsl:choose>
                        <xsl:when
                            test="translate(class,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')='marine'">
                            <xsl:attribute name="class">combat</xsl:attribute>
                        </xsl:when>
                        <xsl:when
                            test="translate(class,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')='combat'">
                            <xsl:attribute name="class">combat</xsl:attribute>
                        </xsl:when>
                        <xsl:when
                            test="translate(class,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')='science'">
                            <xsl:attribute name="class">science</xsl:attribute>
                        </xsl:when>
                        <xsl:when
                            test="translate(class,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')='scientist'">
                            <xsl:attribute name="class">science</xsl:attribute>
                        </xsl:when>
                        <xsl:when
                            test="translate(class,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')='pilot'">
                            <xsl:attribute name="class">piloting</xsl:attribute>
                        </xsl:when>
                        <xsl:when
                            test="translate(class,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')='engineer'">
                            <xsl:attribute name="class">engineering</xsl:attribute>
                        </xsl:when>
                        <xsl:when
                            test="translate(class,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')='diplomat'">
                            <xsl:attribute name="class">diplomacy</xsl:attribute>
                        </xsl:when>
                        <xsl:when
                            test="translate(class,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')='psionic'">
                            <xsl:attribute name="class">psion</xsl:attribute>
                        </xsl:when>
                    </xsl:choose>
                    <tr>
                        <td rowspan="3">
                            <xsl:if test="image">
                                <img>
                                    <xsl:attribute name="src">
                                        <xsl:value-of select="image"/>
                                    </xsl:attribute>
                                    <xsl:attribute name="alt">
                                        <xsl:value-of select="name"/>
                                    </xsl:attribute>
                                    <xsl:attribute name="title">
                                        <xsl:value-of select="name"/>
                                    </xsl:attribute>
                                    <xsl:attribute name="width">100px</xsl:attribute>
                                </img>
                            </xsl:if>
                        </td>
                        <th colspan="2">
                            <xsl:value-of select="name"/>
                        </th>
                    </tr>
                    <tr>
                        <th>
                            <xsl:value-of select="race"/>
                        </th>
                        <th>
                            <xsl:value-of select="class"/>
                        </th>
                    </tr>
                    <tr>
                        <th colspan="2">
                            <xsl:value-of select="player"/>
                        </th>
                    </tr>
                </table>
            </xsl:for-each>
        </div>
    </xsl:template>

    <!--    Process the list of characters in the turn xml-->
    <xsl:template match="character">
        <xsl:variable name="yLocation">
            <xsl:value-of select="(number(substring(location/y,1,string-length(location/y) - 1))-4)*84 + 20 + 
                number(substring(location/y,string-length(location/y),1) - 1) * 16"/>
        </xsl:variable>
        <xsl:variable name="xLocation">
            <xsl:value-of select="(number(substring(location/x,1,string-length(location/x) - 1))-4)*84 + 50 + 
                number(substring(location/x,string-length(location/x),1) - 1) * 16"/>
        </xsl:variable>
        <div>
            <xsl:attribute name="class">character</xsl:attribute>
            <xsl:attribute name="style">
                <xsl:text>margin-top:</xsl:text>
                <xsl:value-of select="$yLocation"/>
                <xsl:text>px;</xsl:text>
                <xsl:text>margin-left:</xsl:text>
                <xsl:value-of select="$xLocation"/>
                <xsl:text>px;</xsl:text>
            </xsl:attribute>
            <a>
                <xsl:attribute name="href">#</xsl:attribute>
                <xsl:attribute name="class">character</xsl:attribute>                
                <xsl:attribute name="name"><xsl:value-of select="name"/></xsl:attribute>
                <xsl:attribute name="title"><xsl:value-of select="name"/></xsl:attribute>
                *
            </a>
        </div>
    </xsl:template>
</xsl:stylesheet>
